pub fn plugin_for_extension(
ext: &str,
) -> Option<&'static (dyn LanguagePlugin + Sync)>Expand description
The plugin handling files with the given extension (without the dot), if any.
pub fn plugin_for_extension(
ext: &str,
) -> Option<&'static (dyn LanguagePlugin + Sync)>The plugin handling files with the given extension (without the dot), if any.