pub fn plugin_for_extension(ext: &str) -> Option<Box<dyn LanguagePlugin>>Expand description
The plugin handling files with the given extension (without the dot), if any.
pub fn plugin_for_extension(ext: &str) -> Option<Box<dyn LanguagePlugin>>The plugin handling files with the given extension (without the dot), if any.